==> getfem-matlab-1.1.tar.gz: getfem-matlab-1.1/matlabint/matlabint_matelemtype.h <==
/* *********************************************************************** */
/*                                                                         */
/* Library : Matlab Interface (matlabint)                                  */
/* File    : matlabint_matelemtype.h : elem. matrices types management.    */
/*     									   */
/*                                                                         */
/* Date : Ocotber 11, 2001.                                                */
/* Author : Yves Renard, Yves.Renard@gmm.insa-tlse.fr                      */
/*                                                                         */
/* *********************************************************************** */
/*                                                                         */
/* Copyright (C) 2001  Yves Renard.                                        */
/*                                                                         */
/* This file is a part of GETFEM++                                         */
/*                                                                         */
/* This program is free software; you can redistribute it and/or modify    */
/* it under the terms of the GNU General Public License as published by    */
/* the Free Software Foundation; version 2 of the License.                 */
/*                                                                         */
/* This program is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
/* GNU General Public License for more details.                            */
/*                                                                         */
/* You should have received a copy of the GNU General Public License       */
/* along with this program; if not, write to the Free Software Foundation, */
/* Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.         */
/*                                                                         */
/* *********************************************************************** */


#ifndef __MATLABINT_MATELEMTYPE_H
#define __MATLABINT_MATELEMTYPE_H

#include <matlabint.h>
#include <getfem_mat_elem_type.h>


namespace matlabint
{
  id_type ind_matelemtype(getfem::pmat_elem_type);
  getfem::pmat_elem_type addr_matelemtype(id_type);
  bool exists_matelemtype(id_type);
  
}  /* end of namespace matlabint.                                          */

#endif /* __MATLABINT_MATELEMTYPE_H                                        */

==> getfem-matlab-1.4.tar.gz: getfem-matlab-1.4/matlabint/matlabint_matelemtype.h <==
/* *********************************************************************** */
/*                                                                         */
/* Library : Matlab Interface (matlabint)                                  */
/* File    : matlabint_matelemtype.h : elem. matrices types management.    */
/*     									   */
/*                                                                         */
/* Date : Ocotber 11, 2001.                                                */
/* Author : Yves Renard, Yves.Renard@gmm.insa-tlse.fr                      */
/*                                                                         */
/* *********************************************************************** */
/*                                                                         */
/* Copyright (C) 2001  Yves Renard.                                        */
/*                                                                         */
/* This file is a part of GETFEM++                                         */
/*                                                                         */
/* This program is free software; you can redistribute it and/or modify    */
/* it under the terms of the GNU General Public License as published by    */
/* the Free Software Foundation; version 2 of the License.                 */
/*                                                                         */
/* This program is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
/* GNU General Public License for more details.                            */
/*                                                                         */
/* You should have received a copy of the GNU General Public License       */
/* along with this program; if not, write to the Free Software Foundation, */
/* Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.         */
/*                                                                         */
/* *********************************************************************** */


#ifndef __MATLABINT_MATELEMTYPE_H
#define __MATLABINT_MATELEMTYPE_H

#include <matlabint_std.h>
#include <getfem_mat_elem_type.h>


namespace matlabint
{
  id_type ind_matelemtype(getfem::pmat_elem_type);
  getfem::pmat_elem_type addr_matelemtype(id_type);
  bool exists_matelemtype(id_type);
  
}  /* end of namespace matlabint.                                          */

#endif /* __MATLABINT_MATELEMTYPE_H                                        */
